pub type DefaultInitProperty<'a, T, P> = Property<'a, T, P, DefaultInit>;Expand description
A shortcut for a Property that is initialized by a DefaultInit.
Aliased Type
pub struct DefaultInitProperty<'a, T, P> { /* private fields */ }pub type DefaultInitProperty<'a, T, P> = Property<'a, T, P, DefaultInit>;A shortcut for a Property that is initialized by a DefaultInit.
pub struct DefaultInitProperty<'a, T, P> { /* private fields */ }