pub trait Init<T, P> { // Required method fn init(&self, obj: &Extended<'_, T>) -> P; }
Defines how a Property is initialized when first accessed.
Property
Creates the initial value for the property on the given object.